# Electron App

Generated by `pd init electron`.

## Structure

- `/src` contains the main application code.

```bash

```

## Install

First, install [Node.js](https://nodejs.org/en/download), [npm](https://docs.npmjs.com/downloading-and-installing-node-js-and-npm)
and [yarn](https://classic.yarnpkg.com/lang/en/docs/install/#mac-stable).

In the root directory of the project, run:

```bash
npm install
```

## Run

In the root directory of the project, run:

```bash
npm start
```

Open [http://localhost:9000](http://localhost:9000) with your browser to see the result.

## Learn More

To learn Electron, check out the [Electron documentation](https://www.electronjs.org/).